complete -c f3d -l input -d "Input Files"
complete -c f3d -l define -s D -d "Define libf3d options"
complete -c f3d -l reset -s R -d "Reset libf3d options"
complete -c f3d -l output -d "Render to file"
complete -c f3d -l no-background -d "No background when render to file"
complete -c f3d -l help -s h -d "Print help"
complete -c f3d -l version -d "Print version details"
complete -c f3d -l list-readers -d "Print the list of readers"
complete -c f3d -l force-reader -d "Force a specific reader to be used, disregarding the file extension"
complete -c f3d -l list-bindings -d "Print the list of interaction bindings and exits, ignored with `--no-render`, only considers the first file group."
complete -c f3d -l config -d "Specify the configuration file to use. absolute/relative path or filename/filestem to search in configuration file locations"
complete -c f3d -l no-config -d "Do not read the configuration file"
complete -c f3d -l no-render -d "Do not render anything and quit right after loading the first file, use with --verbose to recover information about a file."
complete -c f3d -l rendering-backend -d "Backend to use when rendering (auto|glx|wgl|egl|osmesa)"
complete -c f3d -l list-rendering-backends -d "Print the list of rendering backends available on this system"
complete -c f3d -l max-size -d "Maximum size in Mib of a file to load, leave empty for unlimited"
complete -c f3d -l dpi-aware -d "Scale font and window resolution according to system scale"
complete -c f3d -l watch -d "Watch current file and automatically reload it whenever it is modified on disk"
complete -c f3d -l frame-rate -d "Frame rate used to refresh animation and other repeated tasks (watch, UI). Does not impact rendering frame rate."
complete -c f3d -l load-plugins -d "List of plugins to load separated with a comma"
complete -c f3d -l scan-plugins -d "Scan standard directories for plugins and display available plugins (result can be incomplete)"
complete -c f3d -l screenshot-filename -d "Screenshot filename"
complete -c f3d -l verbose -d "Set verbose level, providing more information about the loaded data in the console output"
complete -c f3d -l loading-progress -d "Show loading progress bar"
complete -c f3d -l animation-progress -d "Show animation progress bar"
complete -c f3d -l multi-file-mode -d "Choose the behavior when opening multiple files. \"single\" will show one file at a time, \"all\" will show all files in a single scene, \"dir\" will show files from the same directory in the same scene."
complete -c f3d -l multi-file-regex -d "Regular expression pattern to group files. Captured groups are replaced with \"*\" so that, for example, the pattern \"part(\\d+)\" would group files \"foo-part1.xyz\" and \"foo-part2.xyz\" together as \"foo-part*.xyz\""
complete -c f3d -l recursive-dir-add -d "Add directories recursively"
complete -c f3d -l remove-empty-file-groups -d "Remove file groups that results into an empty scene"
complete -c f3d -l up -d "Up direction"
complete -c f3d -l axis -s x -d "Show axes"
complete -c f3d -l grid -s g -d "Show grid"
complete -c f3d -l x-color -d "Color of the X axis"
complete -c f3d -l y-color -d "Color of the Y axis"
complete -c f3d -l z-color -d "Color of the Z axis"
complete -c f3d -l grid-absolute -d "Position grid at the absolute origin instead of below the model"
complete -c f3d -l grid-unit -d "Size of grid unit square, automatically computed by default"
complete -c f3d -l grid-subdivisions -d "Number of grid subdivisions"
complete -c f3d -l grid-color -d "Color of main grid lines"
complete -c f3d -l axes-grid -d "Enable grid axis"
complete -c f3d -l edges -s e -d "Show cell edges"
complete -c f3d -l armature -d "Enable armature visualization"
complete -c f3d -l camera-index -d "Select the camera to use"
complete -c f3d -l interaction-style -s k -d "Interaction style"
complete -c f3d -l interaction-trackball -d "Enable trackball interaction (deprecated, use --interaction-style=trackball)"
complete -c f3d -l invert-zoom -d "Invert zoom direction with right mouse click"
complete -c f3d -l animation-autoplay -d "Automatically start animation"
complete -c f3d -l animation-index -d "Select animation to show (deprecated)"
complete -c f3d -l animation-indices -d "Select animations to show"
complete -c f3d -l animation-speed-factor -d "Set animation speed factor"
complete -c f3d -l animation-time -d "Set animation time to load"
complete -c f3d -l font-file -d "Path to a FreeType compatible font file"
complete -c f3d -l font-scale -d "Scale fonts"
complete -c f3d -l font-color -d "Set font color"
complete -c f3d -l backdrop-opacity -d "UI backdrop opacity"
complete -c f3d -l command-script -d "Path to a script file containing commands to execute"
complete -c f3d -l normal-glyphs -d "Enable normal glyphs"
complete -c f3d -l point-sprites -s o -d "Select point sprites type (\"none\", \"sphere\", \"gaussian\", \"circle\", \"stddev\", \"bound\")"
complete -c f3d -l point-sprites-type -d "Point sprites type (deprecated)"
complete -c f3d -l point-sprites-size -d "Point sprites sphere size"
complete -c f3d -l point-sprites-absolute-size -d "Do not scale point sprites size by scene size"
complete -c f3d -l point-size -d "Point size when showing vertices, model specified by default"
complete -c f3d -l line-width -d "Line width when showing edges, model specified by default"
complete -c f3d -l backface-type -d "Backface type, can be visible or hidden, model specified by default"
complete -c f3d -l color -d "Solid color"
complete -c f3d -l opacity -d "Opacity"
complete -c f3d -l roughness -d "Roughness coefficient (0.0-1.0)"
complete -c f3d -l metallic -d "Metallic coefficient (0.0-1.0)"
complete -c f3d -l base-ior -d "Index Of Refraction of the base layer (1.0-2.5)"
complete -c f3d -l hdri-file -d "Path to an image file that can be used as a light source and skybox"
complete -c f3d -l hdri-ambient -s f -d "Enable HDRI ambient lighting"
complete -c f3d -l hdri-skybox -s j -d "Enable HDRI skybox background"
complete -c f3d -l texture-matcap -d "Path to a texture file containing a material capture"
complete -c f3d -l texture-base-color -d "Path to a texture file that sets the color of the object"
complete -c f3d -l texture-material -d "Path to a texture file that sets the Occlusion, Roughness and Metallic values of the object"
complete -c f3d -l texture-emissive -d "Path to a texture file that sets the emitted light of the object"
complete -c f3d -l textures-transform -d "3x3 matrix to transform textures"
complete -c f3d -l emissive-factor -d "Emissive factor. This value is multiplied with the emissive color when an emissive texture is present"
complete -c f3d -l texture-normal -d "Path to a texture file that sets the normal map of the object"
complete -c f3d -l checkerboard -d "Apply checkerboard texture to objects"
complete -c f3d -l normal-scale -d "Normal scale affects the strength of the normal deviation from the normal texture"
complete -c f3d -l unlit -d "Ignore shading and make the material unlit"
complete -c f3d -l background-color -d "Background color"
complete -c f3d -l resolution -d "Window resolution"
complete -c f3d -l position -d "Window position"
complete -c f3d -l fps -s z -d "Display rendering frame per second"
complete -c f3d -l filename -d "Display filename"
complete -c f3d -l metadata -s m -d "Display file metadata"
complete -c f3d -l scene-hierarchy -d "Display the scene hierarchy widget"
complete -c f3d -l notifications -d "Display notifications"
complete -c f3d -l hdri-filename -d "Display hdri filename"
complete -c f3d -l blur-background -s u -d "Blur background"
complete -c f3d -l blur-coc -d "Blur circle of confusion radius"
complete -c f3d -l light-intensity -d "Light intensity"
complete -c f3d -l scalar-coloring -s s -d "Color by a scalar array"
complete -c f3d -l coloring-array -d "Name of the array to color with"
complete -c f3d -l coloring-component -s y -d "Component from the array to color with. -1 means magnitude, -2 or the short option, -y, means direct scalars"
complete -c f3d -l coloring-by-cells -s c -d "Use an array from the cells"
complete -c f3d -l coloring-range -d "Custom range for the coloring by array, automatically computed by default"
complete -c f3d -l coloring-scalar-bar -s b -d "Show scalar bar"
complete -c f3d -l colormap-file -d "Specify a colormap image"
complete -c f3d -l colormap-discretization -d "Specify number of colors in colormap"
complete -c f3d -l colormap -d "Specify a custom colormap (ignored if \"colormap-file\" is specified)"
complete -c f3d -l volume-opacity-map -d "Specify a custom opacity map for volume rendering"
complete -c f3d -l volume-opacity-file -d "Specify a custom opacity map image for volume rendering"
complete -c f3d -l volume -s v -d "Show volume if the file is compatible"
complete -c f3d -l volume-inverse -s i -d "Inverse opacity function for volume rendering"
complete -c f3d -l camera-position -d "Camera position (overrides camera direction and camera zoom factor if any)"
complete -c f3d -l camera-focal-point -d "Camera focal point"
complete -c f3d -l camera-view-up -d "Camera view up"
complete -c f3d -l camera-view-angle -d "Camera view angle (non-zero, in degrees)"
complete -c f3d -l camera-direction -d "Camera direction"
complete -c f3d -l camera-zoom-factor -d "Camera zoom factor (non-zero)"
complete -c f3d -l camera-azimuth-angle -d "Camera azimuth angle (in degrees), performed after other camera options"
complete -c f3d -l camera-elevation-angle -d "Camera elevation angle (in degrees), performed after other camera options"
complete -c f3d -l camera-orthographic -d "Use an orthographic camera"
complete -c f3d -l raytracing -s r -d "Enable raytracing"
complete -c f3d -l raytracing-samples -d "Number of samples per pixel"
complete -c f3d -l raytracing-denoise -s d -d "Denoise the image"
complete -c f3d -l blending -s p -d "Select translucency blending mode (\"none\", \"ddp\", \"sort\", \"sort_cpu\" or \"stochastic\")"
complete -c f3d -l translucency-support -d "Enable translucency blending (deprecated)"
complete -c f3d -l ambient-occlusion -s q -d "Enable ambient occlusion providing approximate shadows for better depth perception, implemented using SSAO"
complete -c f3d -l anti-aliasing -s a -d "Select anti-aliasing method (\"none\", \"fxaa\", \"ssaa\" or \"taa\")"
complete -c f3d -l anti-aliasing-mode -d "Select anti-aliasing method (\"fxaa\", \"ssaa\" or \"taa\") (deprecated)"
complete -c f3d -l tone-mapping -s t -d "Enable Tone Mapping, providing balanced coloring"
complete -c f3d -l final-shader -d "Execute the final shader at the end of the rendering pipeline"
complete -c f3d -l display-depth -d "Display depth buffer as grayscale image or with a colormap if \"--scalar-coloring\" is specified"
complete -c f3d -l reference -d "Reference"
complete -c f3d -l reference-threshold -d "Testing threshold"
complete -c f3d -l interaction-test-record -d "Path to an interaction log file to record interactions events to"
complete -c f3d -l interaction-test-play -d "Path to an interaction log file to play interaction events from when loading a file"
